@@ -12,8 +12,8 @@ from itertools import chain
 from dataclasses import dataclass
 
 MAJOR_VERSION = 1
-MINOR_VERSION = 0
-PATCH_VERSION = 2
+MINOR_VERSION = 1
+PATCH_VERSION = 3
 
 LIBRARY_VERSION = f'{MAJOR_VERSION}.{MINOR_VERSION}.{PATCH_VERSION}'
 
@@ -372,6 +372,15 @@ class Crc8(enum.Enum):
         reverse_output=True
     )
 
+    MAXIM_DOW = Configuration(
+        width=8,
+        polynomial=0x31,
+        init_value=0,
+        final_xor_value=0,
+        reverse_input=True,
+        reverse_output=True,
+    )
+
 
 @enum.unique
 class Crc16(enum.Enum):
@@ -479,7 +488,7 @@ def argument_parser():
     t.set_defaults(func=table)
 
     c = subparsers.add_parser('checksum', help='Calculate checksum(s) for the specified input(s)')
-    c.add_argument('inputs', nargs='*', type=argparse.FileType('r'), default=[sys.stdin],
+    c.add_argument('inputs', nargs='*', type=argparse.FileType('rb'), default=[sys.stdin.buffer],
                    help='who will be feed into the crc calculation')
     c.add_argument('-c', '--category', choices=list(CRC_TYPES), default=Crc8.__name__,
                    help='of crc algorithms which shall be used for calculation')
@@ -488,6 +497,10 @@ def argument_parser():
     return parser
 
 
+def _generate_template(width):
+    return '0x{{:0{}X}}'.format((width + 3) // 4)
+
+
 def table(args):
     if not (args.width and args.polynomial):
         return False
@@ -495,7 +508,7 @@ def table(args):
     width = args.width
     polynomial = args.polynomial
     lookup_table = create_lookup_table(width, polynomial)
-    template = '0x{{:0<0{digits}X}}'.format(digits=width // 4)
+    template = _generate_template(width)
     rows = (lookup_table[i:i + columns] for i in range(0, len(lookup_table), columns))
     print(
         "\n".join(
@@ -511,7 +524,7 @@ def checksum(args):
     category = CRC_TYPES[args.category]
     data = bytearray(
         chain.from_iterable(
-            bytes(src.read(), 'utf-8') for src in args.inputs
+            src.read() for src in args.inputs
         )
     )
     for algorithm in sorted(category, key=str):
